#  Copyright (C) 1999-2004
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

proc Bin {value} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin factor $value"
	set bin(factor) [$current(frame) get bin factor]

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc BinAbout {x y} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin about $x $y"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc BinCols {x y z} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin cols \{$x\} \{$y\} \{$z\}"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc BinFilter {str} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin filter \{\{$str\}\}"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc BinToFit {} {
    global current
    global bin
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin to fit"
	set bin(factor) [$current(frame) get bin factor]

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinFactor {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin factor to $bin(factor)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinDepth {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin depth $bin(depth)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinFunction {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin function $bin(function)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinBufferSize {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin buffer size $bin(buffersize)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinSmooth {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin smooth $bin(smooth)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinSmoothFunction {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin smooth function $bin(smooth,function)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc ChangeBinSmoothRadius {} {
    global bin
    global current
    global rgb

    if {$current(frame) != ""} {
	SetWatchCursor
	RGBEvalLock rgb(lock,bin) "$current(frame) bin smooth radius $bin(smooth,radius)"

	UpdateBinDialog
	UpdateContourMenu
	UpdateGraphXAxis
	UnsetWatchCursor
    }
}

proc BinDialog {} {
    global ds9
    global bindialog
    global menu

    # see if we already have a window visible

    if [winfo exist $bindialog(top)] {
	raise $bindialog(top)
	return
    }

    set w $bindialog(top)
    set title "Binning Parameters"

    # create the window

    toplevel $w -colormap $ds9(main)
    wm title $w $title
    wm iconname $w $title
    wm group $w $ds9(top)
    wm protocol $w WM_DELETE_WINDOW BinDestroyDialog

    $w configure -menu $bindialog(mb)

    menu $bindialog(mb) -tearoff 0
    $bindialog(mb) add cascade -label File -menu $bindialog(mb).file
    $bindialog(mb) add cascade -label Edit -menu $bindialog(mb).edit
    $bindialog(mb) add cascade -label Method -menu $bindialog(mb).method
    $bindialog(mb) add cascade -label Block -menu $bindialog(mb).block
    $bindialog(mb) add cascade -label Buffer -menu $bindialog(mb).buffer
    $bindialog(mb) add cascade -label Smooth -menu $bindialog(mb).smooth

    menu $bindialog(mb).file -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).file add command -label "Apply" -command BinApplyDialog
    $bindialog(mb).file add command -label "Clear Filter" \
	-command BinClearFilterDialog
    $bindialog(mb).file add separator
    $bindialog(mb).file add command -label "Close" -command BinDestroyDialog

    menu $bindialog(mb).edit -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).edit add command -label "Cut" -command BinCutDialog
    $bindialog(mb).edit add command -label "Copy" -command BinCopyDialog
    $bindialog(mb).edit add command -label "Paste" -command BinPasteDialog
    $bindialog(mb).edit add command -label "Clear" -command BinClearDialog

    menu $bindialog(mb).method -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).method add radiobutton -label "Average" \
	-variable bin(function) -value average -command ChangeBinFunction
    $bindialog(mb).method add radiobutton -label "Sum" \
	-variable bin(function) -value sum -command ChangeBinFunction

    menu $bindialog(mb).block -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).block add command -label "Block In" -command "Bin .5"
    $bindialog(mb).block add command -label "Block Out" -command "Bin 2"
    $bindialog(mb).block add separator
    $bindialog(mb).block add command -label "Block to Fit Frame" \
	-command "BinToFit"
    $bindialog(mb).block add separator
    $bindialog(mb).block add radiobutton -label "Block 1" \
	-variable bin(factor) -value 1 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 2" \
	-variable bin(factor) -value 2 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 4" \
	-variable bin(factor) -value 4 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 8" \
	-variable bin(factor) -value 8 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 16" \
	-variable bin(factor) -value 16 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 32" \
	-variable bin(factor) -value 32 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 64" \
	-variable bin(factor) -value 64 -command ChangeBinFactor
    $bindialog(mb).block add radiobutton -label "Block 128" \
	-variable bin(factor) -value 128 -command ChangeBinFactor

    menu $bindialog(mb).buffer -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).buffer add radiobutton -label "128x128" \
	-variable bin(buffersize) -value 128 -command ChangeBinBufferSize 
    $bindialog(mb).buffer add radiobutton -label "256x256" \
	-variable bin(buffersize) -value 256 -command ChangeBinBufferSize 
    $bindialog(mb).buffer add radiobutton -label "512x512" \
	-variable bin(buffersize) -value 512 -command ChangeBinBufferSize 
    $bindialog(mb).buffer add radiobutton -label "1024x1024" \
	-variable bin(buffersize) -value 1024 -command ChangeBinBufferSize
    $bindialog(mb).buffer add radiobutton -label "2048x2048" \
	-variable bin(buffersize) -value 2048 -command ChangeBinBufferSize
    $bindialog(mb).buffer add radiobutton -label "4096x4096" \
	-variable bin(buffersize) -value 4096 -command ChangeBinBufferSize

    menu $bindialog(mb).smooth -tearoff 0 -selectcolor $menu(selectcolor)
    $bindialog(mb).smooth add checkbutton -label "Smooth" \
	-variable bin(smooth) -command ChangeBinSmooth
    $bindialog(mb).smooth add separator
    $bindialog(mb).smooth add radiobutton -label "BoxCar" \
	-variable bin(smooth,function) -value boxcar \
	-command ChangeBinSmoothFunction
    $bindialog(mb).smooth add radiobutton -label "TopHat" \
	-variable bin(smooth,function) -value tophat \
	-command ChangeBinSmoothFunction
   $bindialog(mb).smooth add  radiobutton -label "Gaussian" \
	-variable bin(smooth,function) -value gaussian \
	-command ChangeBinSmoothFunction

    frame $w.center -relief groove -borderwidth 2
    frame $w.param -relief groove -borderwidth 2
    frame $w.depth -relief groove -borderwidth 2
    frame $w.smooth -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.center $w.param $w.depth $w.smooth $w.buttons \
	-fill x -ipadx 4 -ipady 4

    label $w.center.title1 -text "Bin Factor"
    entry $w.center.factor -textvariable bindialog(factor) \
	-width 10 -relief sunken -bd 2
    label $w.center.title2 -text "Bin Center"
    entry $w.center.x -textvariable bindialog(x) -width 10 \
	-relief sunken -bd 2
    entry $w.center.y -textvariable bindialog(y) -width 10 \
	-relief sunken -bd 2
    label $w.center.title3 -text "physical"
    label $w.center.dummy -width 9
    checkbutton $w.center.auto -text "or about center" \
	-selectcolor $menu(selectcolor) \
	-variable bindialog(auto)

    grid rowconfigure $w.center 0 -pad 4
    grid rowconfigure $w.center 1 -pad 4
    grid rowconfigure $w.center 2 -pad 4

    grid $w.center.title1 -row 0 -column 0 -padx 4 -sticky w
    grid $w.center.factor -row 0 -column 1 -padx 4 -sticky w
    grid $w.center.title2 -row 1 -column 0 -padx 4 -sticky w
    grid $w.center.x -row 1 -column 1 -padx 4 -sticky w
    grid $w.center.y -row 1 -column 2 -padx 4 -sticky w
    grid $w.center.title3 -row 1 -column 3 -padx 4 -sticky w
    grid $w.center.dummy -row 1 -column 4
    grid $w.center.auto -row 2 -column 1 -padx 4 -sticky w -columnspan 3

    label $w.param.coltitle -text "Bin Columns"
    menubutton $w.param.xcol -textvariable bindialog(xcol) \
	-menu $w.param.xcol.m -relief raised -bd 2 -width 10
    menubutton $w.param.ycol -textvariable bindialog(ycol) \
	-menu $w.param.ycol.m -relief raised -bd 2 -width 10

    label $w.param.filtertitle -text "Bin Filter"
    entry $w.param.filter -textvariable bindialog(filter) \
	-width 40 -relief sunken -bd 2

    grid rowconfigure $w.param 0 -pad 4
    grid rowconfigure $w.param 1 -pad 4

    grid $w.param.coltitle $w.param.xcol $w.param.ycol -padx 4 -sticky w
    grid $w.param.filtertitle $w.param.filter -  -padx 4 -sticky w

    checkbutton $w.depth.ck -text "Bin 3rd Column" \
	-selectcolor $menu(selectcolor) \
	-variable bindialog(3rd) -command UpdateBinDialog

    label $w.depth.coltitle -text "Bin Column"
    menubutton $w.depth.zcol -textvariable bindialog(zcol) \
	-menu $w.depth.zcol.m -relief raised -bd 2 -width 10

    label $w.depth.depthtitle -text "Bin Depth"
    entry $w.depth.depth -textvariable bindialog(depth) \
	-width 10 -relief sunken -bd 2

    label $w.depth.fromtitle -text "Bin from"
    entry $w.depth.from -textvariable bindialog(low) \
	-width 16 -relief sunken -bd 2
    label $w.depth.totitle -text "to"
    entry $w.depth.to -textvariable bindialog(high) \
	-width 16 -relief sunken -bd 2

    checkbutton $w.depth.auto -text "or min max" \
	-selectcolor $menu(selectcolor) \
	-variable bindialog(minmax) -command UpdateBinZCol

    grid rowconfigure $w.depth 0 -pad 4
    grid rowconfigure $w.depth 1 -pad 4
    grid rowconfigure $w.depth 2 -pad 4
    grid rowconfigure $w.depth 3 -pad 4
    grid rowconfigure $w.depth 4 -pad 4

    grid $w.depth.ck -padx 4 -sticky w
    grid $w.depth.coltitle $w.depth.zcol -padx 4 -sticky w
    grid $w.depth.depthtitle $w.depth.depth -padx 4 -sticky w
    grid $w.depth.fromtitle $w.depth.from $w.depth.totitle $w.depth.to \
	-padx 4 -sticky w
    grid  x $w.depth.auto - - -padx 4 -sticky w

    scale $w.smooth.slider -from 1 -to 20 -length 300 \
	-label "Smooth Kernel Radius" \
	-variable bindialog(smooth,radius) \
	-orient horizontal \
	-tickinterval 2 -showvalue false -resolution 1
    entry $w.smooth.value -textvariable bindialog(smooth,radius) \
	-width 7 -relief sunken -bd 2
    pack $w.smooth.slider $w.smooth.value -side left -padx 4

    button $w.buttons.apply -text "Apply" -command BinApplyDialog
    button $w.buttons.clear -text "Clear Filter" -command BinClearFilterDialog
    button $w.buttons.close -text "Close" -command BinDestroyDialog
    pack $w.buttons.apply $w.buttons.clear $w.buttons.close \
	-side left -padx 10 -expand true

    $w.center.factor select range 0 end

    set bindialog(auto) 0
    set bindialog(minmax) 1

    global current
    if {$current(frame) != "" && 
	[$current(frame) has bin] &&
	[$current(frame) get bin depth] > 1} {
	set bindialog(3rd) 1
    } else {
	set bindialog(3rd) 0
    }

    UpdateBinDialog
}

proc PopUp {b m l cmd} {
    destroy $m

    menu $m -tearoff 0
    for {set i 0} {$i<[llength $l]} {incr i} {
	$m add command -label [lindex $l $i] \
	    -command "global bindialog;set $b [lindex $l $i]; $cmd"
    }
}

proc BlankPopUp {m} {
    destroy $m
    menu $m -tearoff 0
}

proc UpdateBinDialog {} {
    global bin
    global bindialog
    global current

    global debug
    if {$debug(tcl,update)} {
	puts "UpdateBinDialog"
    }

    if {[winfo exist $bindialog(top)]} {
	set w $bindialog(top)
	if {$bindialog(3rd)} {
	    $w.depth.coltitle  config -state normal
	    $w.depth.depthtitle config -state normal
	    $w.depth.fromtitle config -state normal
	    $w.depth.totitle config -state normal 
	    $w.depth.auto config -state normal
	} else {
	    $w.depth.coltitle  config -state disabled
	    $w.depth.depthtitle config -state disabled
	    $w.depth.fromtitle config -state disabled
	    $w.depth.totitle config -state disabled 
	    $w.depth.auto config -state disabled
	}

	if {$current(frame) != ""} {
	    if {[$current(frame) has bin]} {
		set cols [$current(frame) get bin cols]
		set colslist "[$current(frame) get bin list]"

		set bindialog(xcol) [lindex $cols 0]
		set bindialog(ycol) [lindex $cols 1]
		PopUp bindialog(xcol) $w.param.xcol.m $colslist {}
		PopUp bindialog(ycol) $w.param.ycol.m $colslist {}

		set cursor [$current(frame) get bin cursor]
		set bindialog(x) [lindex $cursor 0]
		set bindialog(y) [lindex $cursor 1]
		set bindialog(filter) [$current(frame) get bin filter]

		if {$bindialog(3rd)} {
		    set bindialog(zcol) [lindex $cols 2]
		    PopUp bindialog(zcol) $w.depth.zcol.m $colslist \
			UpdateBinZCol

		    if {$bindialog(minmax) && $bindialog(zcol) != ""} {
			set mm [$current(frame) get bin cols minmax \
				    \{$bindialog(zcol)\}]
			set bindialog(low) [lindex $mm 0]
			set bindialog(high) [lindex $mm 1]
		    }
		} else {
		    set bindialog(zcol) {}
		    BlankPopUp $w.depth.zcol.m

		    set bindialog(low) {}
		    set bindialog(high) {}
		}

	    } else {
		set bindialog(xcol) {}
		set bindialog(ycol) {}
		set bindialog(zcol) {}
		BlankPopUp $w.param.xcol.m
		BlankPopUp $w.param.ycol.m
		BlankPopUp $w.depth.zcol.m

		set bindialog(x) {}
		set bindialog(y) {}
		set bindialog(filter) {}

		set bindialog(low) {}
		set bindialog(high) {}
	    }

	    set bindialog(factor) [$current(frame) get bin factor]
	    set bindialog(depth) [$current(frame) get bin depth]
	    set bindialog(smooth,radius) \
		[$current(frame) get bin smooth radius]
	}
    }
}

proc UpdateBinZCol {} {
    global current
    global bindialog

    if {$current(frame) != ""
	&& [$current(frame) has bin]
	&& $bindialog(3rd)
	&& $bindialog(zcol) != ""} {

	if {$bindialog(minmax)} {
	    set mm [$current(frame) get bin cols minmax \{$bindialog(zcol)\}]
	    set bindialog(low) [lindex $mm 0]
	    set bindialog(high) [lindex $mm 1]
	}
    } else {
	    set bindialog(low) {}
	    set bindialog(high) {}
    }
}

proc BinApplyDialog {} {
    global current
    global bin
    global bindialog

    if {$current(frame) != ""} {

	#clean up filter if needed
	set bindialog(filter) [string trimleft $bindialog(filter)]
	set bindialog(filter) [string trimright $bindialog(filter)]

	SetWatchCursor

	if {$bindialog(3rd)} {
	    CubeDialog

	    if {$bindialog(auto)} {
		if {$bindialog(factor) != {}
		    && $bindialog(depth) != {}
		    && $bindialog(low) != {}
		    && $bindialog(high) != {}
		    && $bindialog(xcol) != {}
		    && $bindialog(ycol) != {}
		    && $bindialog(zcol) != {}} {

		    $current(frame) bin to $bindialog(factor) \
			$bindialog(depth) \
			$bindialog(low) $bindialog(high) \
			about center \
			\{$bindialog(xcol)\} \{$bindialog(ycol)\} \
			\{$bindialog(zcol)\} \{$bindialog(filter)\} \
			$bin(smooth) $bin(smooth,function) \
			$bindialog(smooth,radius)
		}
	    } else {
		if {$bindialog(factor) != {}
		    && $bindialog(depth) != {}
		    && $bindialog(low) != {}
		    && $bindialog(high) != {}
		    && $bindialog(x) != {}
		    && $bindialog(y) != {}
		    && $bindialog(xcol) != {}
		    && $bindialog(ycol) != {}
		    && $bindialog(zcol) != {}} {

		    $current(frame) bin to $bindialog(factor) \
			$bindialog(depth) \
			$bindialog(low) $bindialog(high) \
			about $bindialog(x) $bindialog(y) \
			\{$bindialog(xcol)\} \{$bindialog(ycol)\} \
			\{$bindialog(zcol)\} \{$bindialog(filter)\} \
			$bin(smooth) $bin(smooth,function) \
			$bindialog(smooth,radius)
		}
	    }
	} else {
	    if {$bindialog(auto)} {
		if {$bindialog(factor) != {}
		    && $bindialog(xcol) != {}
		    && $bindialog(ycol) != {}} {

		    $current(frame) bin to $bindialog(factor) \
			about center \
			\{$bindialog(xcol)\} \{$bindialog(ycol)\} \
			\{$bindialog(filter)\} \
			$bin(smooth) $bin(smooth,function) \
			$bindialog(smooth,radius)
		}
	    } else {
		if {$bindialog(factor) != {}
		    && $bindialog(x) != {}
		    && $bindialog(y) != {}
		    && $bindialog(xcol) != {}
		    && $bindialog(ycol) != {}} {

		    $current(frame) bin to $bindialog(factor) \
			about $bindialog(x) $bindialog(y) \
			\{$bindialog(xcol)\} \{$bindialog(ycol)\} \
			\{$bindialog(filter)\} \
			$bin(smooth) $bin(smooth,function) \
			$bindialog(smooth,radius)
		}
	    }
	}

	UpdateContourMenu
	UpdateCubeDialog
	UpdateGraphXAxis
	UnsetWatchCursor

	# the bining center will shift
	UpdateBinDialog
    }

    # reset
    set bindialog(auto) 0
}

proc BinClearFilterDialog {} {
    global bindialog

    $bindialog(top).param.filter delete 0 end
}

proc BinDestroyDialog {} {
    global bindialog

    destroy $bindialog(top)
    destroy $bindialog(mb)
}

proc BinCutDialog {} {
    global bindialog

    set w [focus -displayof $bindialog(top)]

    if {![catch {set data [string range [$w get] [$w index sel.first] [expr {[$w index sel.last] - 1}]]}]} {
        clipboard clear -displayof $w
        clipboard append -displayof $w $data
        $w delete sel.first sel.last
    }
}

proc BinCopyDialog {} {
    global bindialog

    set w [focus -displayof $bindialog(top)]

    if {![catch {set data [string range [$w get] [$w index sel.first] [expr {[$w index sel.last] - 1}]]}]} {
        clipboard clear -displayof $w
        clipboard append -displayof $w $data
    }
}

proc BinPasteDialog {} {
    global tcl_platform
    global bindialog

    set w [focus -displayof $bindialog(top)]

    catch {
        if {"$tcl_platform(platform)" != "unix"} {
            catch {
                $w delete sel.first sel.last
            }
        }
        $w insert insert [selection get -displayof $w -selection CLIPBOARD]
        tkEntrySeeInsert $w
    }
}

proc BinClearDialog {} {
    global bindialog

    set w [focus -displayof $bindialog(top)]

    if {![catch {selection get -displayof $bindialog(top)}]} {
	$w delete sel.first sel.last
    }
}

proc UpdateBinMenu {} {
    global current
    global bin
    global buttons
    global ds9
    global bin
    global menu

    global debug
    if {$debug(tcl,update)} {
	puts "UpdateBinMenu"
    }

    if {$current(frame) != ""} {
	if {[$current(frame) has fits]} {
	    if {[$current(frame) has bin]} {
		$ds9(mb) entryconfig $menu(bin) -state normal
		$buttons(name).major.bin1 configure -state normal
	    } else {
		$ds9(mb) entryconfig $menu(bin) -state disabled
		$buttons(name).major.bin1 configure -state disabled
	    }
	} else {
	    $ds9(mb) entryconfig $menu(bin) -state normal
	    $buttons(name).major.bin1 configure -state normal
	}

	set bin(function) [$current(frame) get bin function]
	set bin(factor) [$current(frame) get bin factor]	    
	set bin(depth) [$current(frame) get bin depth]
	set bin(buffersize) [$current(frame) get bin buffer size]
	set bin(smooth) [$current(frame) get bin smooth]
	set bin(smooth,function) [$current(frame) get bin smooth function]
	set bin(smooth,radius) [$current(frame) get bin smooth radius]
    } else {
	$ds9(mb) entryconfig $menu(bin) -state disabled
	$buttons(name).major.bin1 configure -state disabled
    }
}

proc ProcessBinCmd {varname iname} {
    upvar $varname var
    upvar $iname i

    global bin

    switch -- [string tolower [lindex $var $i]] {
	about {
	    BinAbout [lindex $var [expr $i+1]] [lindex $var [expr $i+2]]
	    incr i 2
	}
	buffersize {
	    incr i
	    set bin(buffersize) [lindex $var $i]
	    ChangeBinBufferSize
	}
	cols {
	    BinCols \"[lindex $var [expr $i+1]]\" \"[lindex $var [expr $i+2]]\" \"[lindex $var [expr $i+3]]\"
	    incr i 3
	}
	factor {
	    incr i
	    set bin(factor) [lindex $var $i]
	    ChangeBinFactor
	}
	depth {
	    incr i
	    set bin(depth) [lindex $var $i]
	    ChangeBinDepth
	}
	filter {
	    incr i
	    BinFilter [lindex $var $i]
	}
	function {
	    incr i
	    set bin(function) [string tolower [lindex $var $i]]
	    ChangeBinFunction
	}
	to {
	    # eat the 'fit'
	    incr i
	    BinToFit
	}
	smooth {
	    incr i
	    switch -- [string tolower [lindex $var $i]] {
		radius {
		    incr i
		    set bin(smooth,radius) [lindex $var $i]
		    ChangeBinSmoothRadius
		}
		function {
		    incr i
		    set bin(smooth,function) [lindex $var $i]
		    ChangeBinSmoothFunction
		}
		default {
		    set bin(smooth) [FromYesNo [lindex $var $i]]
		    ChangeBinSmooth
		}
	    }
	}
    }
}

