#  Copyright (C) 1999-2004
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

proc ExportDialog {} {
    global ed
    global menu
    global export
    global exportfbox

    set w ".export"

    set ed(ok) 0
    set ed(format) $export(format)

    DialogCreate $w "Export Data as" -borderwidth 2
    frame $w.format -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.format $w.buttons -ipadx 4 -ipady 4 -fill x -expand true

    label $w.format.title -text "Format"
    radiobutton $w.format.fits -text FITS \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value fits
    radiobutton $w.format.jpeg -text JPEG \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value jpeg -state disabled
    radiobutton $w.format.tiff -text "TIFF RGB 24-bit" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value tiff -state disabled
    radiobutton $w.format.png -text "PNG 24-bit (Portable Network Graphics)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value png -state disabled
    radiobutton $w.format.ppm -text "PPM RGB (Portable Pixmap)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value ppm -state disabled
    radiobutton $w.format.mpeg -text "MPEG-1 (Movie)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value mpeg -state disabled

    grid $w.format.fits -ipadx 4 -sticky w
    grid $w.format.jpeg -ipadx 4 -sticky w
    grid $w.format.tiff -ipadx 4 -sticky w
    grid $w.format.png -ipadx 4 -sticky w
    grid $w.format.ppm -ipadx 4 -sticky w
    grid $w.format.mpeg -ipadx 4 -sticky w

    button $w.buttons.ok -text "OK" -default active -command {set ed(ok) 1}
    button $w.buttons.cancel -text "Cancel" -command {set ed(ok) 0}
    pack $w.buttons.ok -side left -padx 10
    pack $w.buttons.cancel -side right -padx 10

    bind $w <Return> {set ed(ok) 1}
    bind $w <Alt-o> "tkButtonInvoke $w.buttons.ok"
    bind $w <Alt-c> "tkButtonInvoke $w.buttons.cancel"

    DialogCenter $w 
    DialogWait $w ed(ok)
    DialogDismiss $w

    if {$ed(ok)} {
	set export(format) $ed(format)

	switch -- $export(format) {
	    fits {
		set export(fn) "$export(base).fits"
		set exportfbox(types) {
		    {"FITS files"   *.fits}
		    {"All files"    *}
		}
	    }
	    jpeg {
		set export(fn) "$export(base).jpg"
		set exportfbox(types) {
		    {"JPEG files"   *.jpg}
		    {"All files"    *}
		}
	    }
	    tiff {
		set export(fn) "$export(base).tif"
		set exportfbox(types) {
		    {"TIFF files"   *.tif }
		    {"All files"    *}
		}
	    }
	    png {
		set export(fn) "$export(base).png"
		set exportfbox(types) {
		    {"PNG files"    *.png }
		    {"All files"    *}
		}
	    }
	    ppm	{
		set export(fn) "$export(base).ppm"
		set exportfbox(types) {
		    {"PPM files"    *.ppm }
		    {"All files"    *}
		}
	    }
	    mpeg {
		set export(fn) "$export(base).mpg"
		set exportfbox(types) {
		    {"MPEG files"    *.mpg }
		    {"All files"    *}
		}
	    }
	}
	FileLast exportfbox $export(fn)
	set export(fn) [SaveFileDialog exportfbox]
	set export(base) [file rootname [file tail $export(fn)]]

	switch -- $export(format) {
	    fits {}
	    jpeg {}
	    tiff {}
	    png {}
	    ppm	{}
	    mpeg {}
	}

	if {$export(fn) != {}} {
	    Export
	}
    }
    destroy $w 
    unset ed
}

proc Export {} {
    global export
    global current
    global ds9

    set depth [$current(frame) get fits depth]
    if {$ds9(display,mode) == "single" \
	    && $depth > 1 \
	    && $export(format) != "fits"} {

	set slice [$current(frame) get fits slice]
	set fn $export(fn)
	
	# loop thru datacube
	for {set ii 1} {$ii <= $depth} {incr ii} {
	    set export(fn) "[file root $fn]_$ii[file extension $fn]"
	    $current(frame) update fits slice $ii
	    ContourUpdateNow

	    ExportDoit
	}

	# reset current slice
	$current(frame) update fits slice $slice
	ContourUpdateNow

    } else {
	ExportDoit
    }
}

proc ExportDoit {} {
    global export
    global current

    RealizeDS9

    switch -- $export(format) {
	fits {$current(frame) save fits image file "\{$export(fn)\}"}
	jpeg {}
	tiff {}
	png {}
	ppm {}
	mpeg {}
    }
}

proc ProcessExportCmd {varname iname} {
    upvar $varname var
    upvar $iname i

    global export
    
    incr i
    set export(format) [string tolower [lindex $var $i]]
    incr i
    set export(fn) [lindex $var $i]

    if {$export(fn) != {}} {
	Export
    }
}

# SaveAs

proc SaveAsDialog {} {
    global ed
    global menu
    global saveas
    global saveasfbox

    set w ".saveas"

    set ed(ok) 0
    set ed(format) $saveas(format)

    DialogCreate $w "Save Image as" -borderwidth 2
    frame $w.format -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.format $w.buttons -ipadx 4 -ipady 4 -fill x -expand true

    label $w.format.title -text "Format"
    radiobutton $w.format.fits -text FITS \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value fits
    radiobutton $w.format.jpeg -text JPEG \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value jpeg
    radiobutton $w.format.tiff -text "TIFF RGB 24-bit" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value tiff
    radiobutton $w.format.png -text "PNG 24-bit (Portable Network Graphics)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value png
    radiobutton $w.format.ppm -text "PPM RGB (Portable Pixmap)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value ppm
    radiobutton $w.format.mpeg -text "MPEG-1 (Movie)" \
	-selectcolor $menu(selectcolor) \
	-variable ed(format) -value mpeg

    grid $w.format.fits -ipadx 4 -sticky w
    grid $w.format.jpeg -ipadx 4 -sticky w
    grid $w.format.tiff -ipadx 4 -sticky w
    grid $w.format.png -ipadx 4 -sticky w
    grid $w.format.ppm -ipadx 4 -sticky w
    grid $w.format.mpeg -ipadx 4 -sticky w

    button $w.buttons.ok -text "OK" -default active -command {set ed(ok) 1}
    button $w.buttons.cancel -text "Cancel" -command {set ed(ok) 0}
    pack $w.buttons.ok -side left -padx 10
    pack $w.buttons.cancel -side right -padx 10

    bind $w <Return> {set ed(ok) 1}
    bind $w <Alt-o> "tkButtonInvoke $w.buttons.ok"
    bind $w <Alt-c> "tkButtonInvoke $w.buttons.cancel"

    DialogCenter $w 
    DialogWait $w ed(ok)
    DialogDismiss $w

    if {$ed(ok)} {
	set saveas(format) $ed(format)

	switch -- $saveas(format) {
	    fits {
		set saveas(fn) "$saveas(base).fits"
		set saveasfbox(types) {
		    {"FITS files"   *.fits}
		    {"All files"    *}
		}
	    }
	    jpeg {
		set saveas(fn) "$saveas(base).jpg"
		set saveasfbox(types) {
		    {"JPEG files"   *.jpg}
		    {"All files"    *}
		}
	    }
	    tiff {
		set saveas(fn) "$saveas(base).tif"
		set saveasfbox(types) {
		    {"TIFF files"   *.tif }
		    {"All files"    *}
		}
	    }
	    png {
		set saveas(fn) "$saveas(base).png"
		set saveasfbox(types) {
		    {"PNG files"    *.png }
		    {"All files"    *}
		}
	    }
	    ppm	{
		set saveas(fn) "$saveas(base).ppm"
		set saveasfbox(types) {
		    {"PPM files"    *.ppm }
		    {"All files"    *}
		}
	    }
	    mpeg {
		set saveas(fn) "$saveas(base).mpg"
		set saveasfbox(types) {
		    {"MPEG files"    *.mpg }
		    {"All files"    *}
		}
	    }
	}
	FileLast saveasfbox $saveas(fn)
	set saveas(fn) [SaveFileDialog saveasfbox]
	set saveas(base) [file rootname [file tail $saveas(fn)]]

	set saveas(ok) 1
	if {$saveas(fn) != {}} {
	    switch -- $saveas(format) {
		fits {}
		jpeg {set saveas(ok) [SaveAsJPEGDialog]}
		tiff {set saveas(ok) [SaveAsTIFFDialog]}
		png {}
		ppm {}
		mpeg {set saveas(ok) [SaveAsMPEGDialog]}
	    }
	}

	if {$saveas(fn) != {} && $saveas(ok)} {
	    SaveAs
	}
    }
    destroy $w 
    unset ed
}

proc SaveAsJPEGDialog {} {
    global eds
    global saveas
    global menu

    set w ".saveasjpeg"

    set eds(ok) 0
    set eds(quality) $saveas(jpeg,quality)

    DialogCreate $w "SaveAs JPEG" -borderwidth 2
    frame $w.param -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.param $w.buttons -ipadx 4 -ipady 4 -fill x -expand true

    scale $w.param.quality -from 0 -to 100 -length 300 \
	-variable eds(quality) \
	-orient horizontal -label "JPEG Quality Factor" \
	-tickinterval 25 -showvalue true -resolution 1

    grid $w.param.quality -ipadx 4 -sticky w

    button $w.buttons.ok -text "OK" -default active -command {set eds(ok) 1}
    button $w.buttons.cancel -text "Cancel" -command {set eds(ok) 0}
    pack $w.buttons.ok -side left -padx 10
    pack $w.buttons.cancel -side right -padx 10

    bind $w <Return> {set eds(ok) 1}
    bind $w <Alt-o> "tkButtonInvoke $w.buttons.ok"
    bind $w <Alt-c> "tkButtonInvoke $w.buttons.cancel"

    DialogCenter $w 
    DialogWait $w eds(ok)
    DialogDismiss $w

    set r 0
    if {$eds(ok)} {
	set saveas(jpeg,quality) $eds(quality)
	set r 1
    }
    destroy $w 
    unset eds

    return $r
}

proc SaveAsTIFFDialog {} {
    global eds
    global saveas
    global menu

    set w ".saveastiff"

    set eds(ok) 0
    set eds(compression) $saveas(tiff,compression)

    DialogCreate $w "SaveAs TIFF" -borderwidth 2
    frame $w.param -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.param $w.buttons -ipadx 4 -ipady 4 -fill x -expand true

    label $w.param.title -text "Compression:"
    radiobutton $w.param.none -text "None" \
	-selectcolor $menu(selectcolor) \
	-variable eds(compression) -value none
    radiobutton $w.param.jpeg -text "JPEG" \
	-selectcolor $menu(selectcolor) \
	-variable eds(compression) -value jpeg
    radiobutton $w.param.packbits -text "Packbits" \
	-selectcolor $menu(selectcolor) \
	-variable eds(compression) -value packbits
    radiobutton $w.param.deflate -text "Deflate" \
	-selectcolor $menu(selectcolor) \
	-variable eds(compression) -value deflate

    grid $w.param.title -ipadx 4 -sticky w
    grid $w.param.none -ipadx 4 -sticky w
    grid $w.param.jpeg -ipadx 4 -sticky w
    grid $w.param.packbits -ipadx 4 -sticky w
    grid $w.param.deflate -ipadx 4 -sticky w

    button $w.buttons.ok -text "OK" -default active -command {set eds(ok) 1}
    button $w.buttons.cancel -text "Cancel" -command {set eds(ok) 0}
    pack $w.buttons.ok -side left -padx 10
    pack $w.buttons.cancel -side right -padx 10

    bind $w <Return> {set eds(ok) 1}
    bind $w <Alt-o> "tkButtonInvoke $w.buttons.ok"
    bind $w <Alt-c> "tkButtonInvoke $w.buttons.cancel"

    DialogCenter $w 
    DialogWait $w eds(ok)
    DialogDismiss $w

    set r 0
    if {$eds(ok)} {
	set saveas(tiff,compression) $eds(compression)
	set r 1
    }
    destroy $w 
    unset eds

    return $r
}

proc SaveAsMPEGDialog {} {
    global eds
    global saveas
    global menu

    set w ".saveasmpeg"

    set eds(ok) 0
    set eds(quality) $saveas(mpeg,quality)

    DialogCreate $w "SaveAs MPEG" -borderwidth 2
    frame $w.param -relief groove -borderwidth 2
    frame $w.buttons -relief groove -borderwidth 2
    pack $w.param $w.buttons -ipadx 4 -ipady 4 -fill x -expand true

    scale $w.param.quality -from 2 -to 31 -length 300 \
	-variable eds(quality) \
	-orient horizontal -label "MPEG Quality Factor" \
	-tickinterval 4 -showvalue true -resolution 1

    grid $w.param.quality -ipadx 4 -sticky w

    button $w.buttons.ok -text "OK" -default active -command {set eds(ok) 1}
    button $w.buttons.cancel -text "Cancel" -command {set eds(ok) 0}
    pack $w.buttons.ok -side left -padx 10
    pack $w.buttons.cancel -side right -padx 10

    bind $w <Return> {set eds(ok) 1}
    bind $w <Alt-o> "tkButtonInvoke $w.buttons.ok"
    bind $w <Alt-c> "tkButtonInvoke $w.buttons.cancel"

    DialogCenter $w 
    DialogWait $w eds(ok)
    DialogDismiss $w

    set r 0
    if {$eds(ok)} {
	set saveas(mpeg,quality) $eds(quality)
	set r 1
    }
    destroy $w 
    unset eds

    return $r
}

proc SaveAs {} {
    global saveas
    global canvas
    global current
    global ds9
    global cube

    # besure we are on top
    raise $ds9(top)

    set bg [$canvas(name) cget -background]
    $canvas(name) configure -background white -relief flat
    $current(frame) highlite no

    switch -- $saveas(format) {
	fits -
	jpeg -
	tiff -
	png -
	ppm {
	    set depth [$current(frame) get fits depth]
	    if {$ds9(display,mode) == "single" && $depth > 1} {
		set slice [$current(frame) get fits slice]
		set fn $saveas(fn)
		
		# loop thru datacube
		for {set ii 1} {$ii <= $depth} {incr ii} {
		    set saveas(fn) "[file root $fn]_$ii[file extension $fn]"

		    set cube(slice) $ii
		    $current(frame) update fits slice $ii
		    ContourUpdateNow

		    SaveAsDoit
		}

		# reset current slice
		$current(frame) update fits slice $slice
		ContourUpdateNow

	    } else {
		SaveAsDoit
	    }
	}
	mpeg {
	    set depth [$current(frame) get fits depth]
	    set slice [$current(frame) get fits slice]
		
	    # loop thru datacube
	    set saveas(mpeg,first) 1
	    for {set ii 1} {$ii <= $depth} {incr ii} {

		set cube(slice) $ii
		$current(frame) update fits slice $ii
		ContourUpdateNow
		
		SaveAsDoit

		set saveas(mpeg,first) 0
	    }
	    mpeg close

	    # reset current slice
	    set cube(slice) $slice
	    $current(frame) update fits slice $slice
	    ContourUpdateNow
	}
    }

    $current(frame) highlite yes
    $canvas(name) configure -background $bg -relief groove
}

proc SaveAsDoit {} {
    global saveas
    global canvas
    global current

    RealizeDS9

    set r \
	[catch {image create photo -format window -data $canvas(name)} ph]
    if {$r != 0} {
	Error "Unable to create photo"
	return
    }

    switch -- $saveas(format) {
	fits {
	    $current(frame) save fits resample file "\{$saveas(fn)\}"
	}
	jpeg {
	    $ph write $saveas(fn) -format \
		[list $saveas(format) -quality $saveas(jpeg,quality)]
	}
	tiff {
	    $ph write $saveas(fn) -format \
		[list $saveas(format) \
		     -compression $saveas(tiff,compression)]
	}
	png {$ph write $saveas(fn) -format $saveas(format)}
	ppm {$ph write $saveas(fn) -format $saveas(format)}
	mpeg {
	    if {$saveas(mpeg,first)} {
		set w [image width $ph]
		set h [image height $ph]
		mpeg create $saveas(fn) $w $h 25 30 $saveas(mpeg,quality)
	    }
	    mpeg add $ph
	}
    }
}

proc ProcessSaveAsCmd {varname iname} {
    upvar $varname var
    upvar $iname i

    global saveas
    
    set saveas(format) [string tolower [lindex $var $i]]
    incr i
    set saveas(fn) [lindex $var $i]

    if {$saveas(fn) != {}} {
	SaveAs
    }
}

