#! /bin/sh

echo "XPA Tests"

echo "Starting DS9..."
if [ `xpaaccess ds9` = no ]; then
    ../ds9&

    i=1
    while [ "$i" -le 15 ]
	do
	sleep 1
	if [ `xpaaccess ds9` = yes ]; then
	    break
	fi

	i=`expr $i + 1`
    done
fi

# load default image
xpaset -p ds9 scale zscale
xpaset -p ds9 file img16.fits

if [ "$1" = "about" -o  -z "$1" ]; then
echo "Testing About"
xpaget ds9 about > /dev/null
echo "PASSED"
fi

if [ "$1" = "array" -o  -z "$1" ]; then
echo "Testing Array"
xpaget ds9 array > /dev/null
echo "PASSED"
fi

if [ "$1" = "bin" -o  -z "$1" ]; then
echo "Testing Bin"
xpaset -p ds9 file new table.fits
xpaset -p ds9 bin factor 4
xpaset -p ds9 scale log
xpaset -p ds9 scale minmax
xpaset -p ds9 bin buffersize 1024
xpaset -p ds9 bin filter 'circle(4096,4096,200)'
xpaset -p ds9 bin filter ""
xpaset -p ds9 bin cols rawx rawy
xpaset -p ds9 bin about 2048 2048
xpaset -p ds9 bin filter
xpaset -p ds9 bin function sum
xpaset -p ds9 bin to fit
xpaset -p ds9 bin smooth yes
xpaset -p ds9 bin smooth function tophat
xpaset -p ds9 bin smooth radius 5
xpaset -p ds9 bin smooth no
xpaget ds9 bin about > /dev/null
xpaget ds9 bin buffersize > /dev/null
xpaget ds9 bin cols > /dev/null
xpaget ds9 bin factor > /dev/null
xpaget ds9 bin filter > /dev/null
xpaget ds9 bin function > /dev/null
xpaget ds9 bin smooth > /dev/null
xpaget ds9 bin smooth function > /dev/null
xpaget ds9 bin smooth radius > /dev/null
xpaset -p ds9 frame delete
echo "PASSED"
fi

if [ "$1" = "contour" -o  -z "$1" ]; then
echo "Testing Contour"
xpaget ds9 contour > /dev/null
xpaset -p ds9 contour yes
xpaset -p ds9 contour copy
xpaset -p ds9 contour paste wcs fk5
xpaset -p ds9 contour save foo.con wcs fk5
xpaset -p ds9 contour no
xpaset -p ds9 contour load foo.con wcs fk5 red 2
xpaset -p ds9 contour no
rm -f foo.con
echo "PASSED"
fi

if [ "$1" = "cmap" -o  -z "$1" ]; then
echo "Testing Cmap"
xpaget ds9 cmap > /dev/null
xpaget ds9 cmap file > /dev/null
xpaget ds9 cmap invert > /dev/null
xpaget ds9 cmap value > /dev/null
xpaset -p ds9 cmap Heat
xpaset -p ds9 cmap file blue.sao
xpaset -p ds9 cmap invert yes
xpaset -p ds9 cmap value 5 .2
xpaset -p ds9 cmap Grey
echo "PASSED"
fi

if [ "$1" = "crosshair" -o  -z "$1" ]; then
echo "Testing Crosshair"
xpaget ds9 crosshair > /dev/null
xpaget ds9 crosshair wcs fk5 sexagesimal > /dev/null
xpaset -p ds9 crosshair 13:29:55.287 +47:11:37.73 wcs fk5
xpaset -p ds9 mode pointer
echo "PASSED"
fi

if [ "$1" = "cursor" -o  -z "$1" ]; then
echo "Testing Cursor"
xpaset -p ds9 mode crosshair
xpaset -p ds9 cursor 10 10
xpaset -p ds9 mode pointer
echo "PASSED"
fi

if [ "$1" = "dss" ]; then
echo "Testing DSS"
xpaget ds9 dss server > /dev/null
xpaget ds9 dss survey > /dev/null
xpaget ds9 dss name > /dev/null
xpaget ds9 dss x > /dev/null
xpaget ds9 dss y > /dev/null
xpaget ds9 dss width > /dev/null
xpaget ds9 dss height > /dev/null
xpaget ds9 dss > /dev/null
xpaset -p ds9 dss server sao
xpaset -p ds9 dss survey dss
xpaset -p ds9 dss width 10
xpaset -p ds9 dss height 10
xpaset -p ds9 dss m31
echo "PASSED"
fi

if [ "$1" = "file" -o  -z "$1" ]; then
echo "Testing File"
xpaget ds9 file > /dev/null

echo "..fits new"
xpaset -p ds9 file new img16.fits
xpaset -p ds9 frame delete

echo "..file save"
xpaset -p ds9 file img16.fits
xpaset -p ds9 file save foo.fits
echo "..file save gz"
xpaset -p ds9 file save gz foo.fits.gz
echo "..file save resample"
xpaset -p ds9 file save resample foo.fits
echo "..file save resample gz"
xpaset -p ds9 file save resample gz foo.fits.gz
rm -f foo.fits foo.fits.gz

echo "PASSED"
fi

if [ "$1" = "fits" -o  -z "$1" ]; then
echo "Testing Fits"

echo "..fits new"
cat img16.fits | xpaset ds9 fits new 
xpaset -p ds9 frame delete

echo "..get table"
cat table.fits | xpaset ds9 fits
xpaget ds9 fits table > foo.fits
echo "..get table gz"
xpaget ds9 fits table gz > foo.fits.gz

echo "..get fits"
xpaset -p ds9 file img16.fits
xpaget ds9 fits size > /dev/null
xpaget ds9 fits size wcs arcsec > /dev/null
xpaget ds9 fits depth > /dev/null
xpaget ds9 fits header > /dev/null
xpaget ds9 fits header 1 > /dev/null
xpaget ds9 fits type > /dev/null
xpaget ds9 fits > foo.fits

echo "..get image"
xpaget ds9 fits image > foo.fits
echo "..get image gz"
xpaget ds9 fits image gz > foo.fits.gz
echo "..get fits resample"
xpaget ds9 fits resample > foo.fits
echo "..get fits resample gz"
xpaget ds9 fits resample gz > foo.fits.gz
rm -f foo.fits foo.fits.gz

echo "PASSED"
fi

if [ "$1" = "frame" -o  -z "$1" ]; then
echo "Testing Frame"
xpaset -p ds9 frame new rgb
xpaset -p ds9 frame delete
xpaset -p ds9 frame new
xpaset -p ds9 file img16.fits
xpaget ds9 frame > /dev/null
xpaget ds9 frame frameno > /dev/null
xpaget ds9 frame all > /dev/null
xpaget ds9 frame active > /dev/null
xpaset -p ds9 frame center
xpaset -p ds9 frame center 1
xpaset -p ds9 frame center all
xpaset -p ds9 frame reset
xpaset -p ds9 frame reset 1
xpaset -p ds9 frame reset all
xpaset -p ds9 frame refresh
xpaset -p ds9 frame refresh 1
xpaset -p ds9 frame refresh all
xpaset -p ds9 frame hide
xpaset -p ds9 frame hide 1
xpaset -p ds9 frame hide all
xpaset -p ds9 frame show
xpaset -p ds9 frame show 1
xpaset -p ds9 frame show all
xpaset -p ds9 frame first
xpaset -p ds9 frame next
xpaset -p ds9 frame prev
xpaset -p ds9 frame last
xpaset -p ds9 frame frameno 1
xpaset -p ds9 frame 2
xpaset -p ds9 frame clear
xpaset -p ds9 frame clear 1
xpaset -p ds9 frame clear all
xpaset -p ds9 frame delete
xpaset -p ds9 frame delete 1
xpaset -p ds9 frame delete all
xpaset -p ds9 file new img16.fits
echo "PASSED"
fi

if [ "$1" = "grid" -o  -z "$1" ]; then
echo "Testing Grid"
xpaget ds9 grid > /dev/null
xpaget ds9 grid system > /dev/null
xpaget ds9 grid sky > /dev/null
xpaget ds9 grid skyformat > /dev/null
xpaget ds9 grid type > /dev/null
xpaget ds9 grid type axes > /dev/null
xpaget ds9 grid type numerics > /dev/null
xpaget ds9 grid view grid > /dev/null
xpaget ds9 grid view axes > /dev/null
xpaget ds9 grid view axes numbers > /dev/null
xpaget ds9 grid view axes tickmarks > /dev/null
xpaget ds9 grid view axes label > /dev/null
xpaget ds9 grid view title > /dev/null
xpaget ds9 grid view border > /dev/null
xpaget ds9 grid view vertical > /dev/null

xpaset -p ds9 grid yes
xpaset -p ds9 grid system wcs
xpaset -p ds9 grid sky fk5
xpaset -p ds9 grid skyformat degrees
xpaset -p ds9 grid type analysis
xpaset -p ds9 grid type axes interior
xpaset -p ds9 grid type numerics interior
xpaset -p ds9 grid view grid yes
xpaset -p ds9 grid view axes yes
xpaset -p ds9 grid view axes numbers yes
xpaset -p ds9 grid view axes tickmarks yes
xpaset -p ds9 grid view axes label yes
xpaset -p ds9 grid view title yes
xpaset -p ds9 grid view border yes
xpaset -p ds9 grid view vertical no

xpaset -p ds9 grid no
echo "PASSED"
fi

if [ "$1" = "iconify" -o  -z "$1" ]; then
echo "Testing Iconify"
xpaget ds9 iconify > /dev/null
xpaset -p ds9 iconify yes
xpaset -p ds9 iconify no
echo "PASSED"
fi

if [ "$1" = "iis" -o  -z "$1" ]; then
echo "Testing IIS"
xpaget ds9 iis file name > /dev/null
xpaget ds9 iis file name 1 > /dev/null
xpaset -p ds9 iis filename foo.fits
xpaset -p ds9 iis filename foo.fits 1
echo "PASSED"
fi

if [ "$1" = "imexam" -o  -z "$1" ]; then
echo "Testing imexam"
echo "Select coordinate point:"
xpaget ds9 imexam coordinate wcs fk5 degrees > /dev/null
echo "  ok"
echo "Select value point:"
xpaget ds9 imexam value > /dev/null
echo "  ok"
echo "PASSED"
fi

if [ "$1" = "raise" -o  -z "$1" ]; then
echo "Testing Lower/Raise"
xpaget ds9 iconify > /dev/null
xpaset -p ds9 lower
xpaset -p ds9 raise
echo "PASSED"
fi

if [ "$1" = "match" -o  -z "$1" ]; then
echo "Testing Match"
xpaset -p ds9 tile
xpaset -p ds9 file new img-32.fits
xpaset -p ds9 match frames wcs
xpaset -p ds9 match colorbars
xpaset -p ds9 match scales
xpaset -p ds9 single
xpaset -p ds9 frame delete
xpaset -p ds9 match frames image
echo "PASSED"
fi

if [ "$1" = "minmax" -o  -z "$1" ]; then
echo "Testing MinMax"
xpaget ds9 minmax > /dev/null
xpaget ds9 minmax mode > /dev/null
xpaget ds9 minmax sample > /dev/null
xpaset -p ds9 minmax scan
xpaset -p ds9 minmax mode scan
xpaset -p ds9 minmax sample 10
echo "PASSED"
fi

if [ "$1" = "mode" -o  -z "$1" ]; then
echo "Testing Mode"
xpaget ds9 mode > /dev/null
xpaset -p ds9 mode none
xpaset -p ds9 mode crosshair
xpaset -p ds9 mode colorbar
xpaset -p ds9 mode pan
xpaset -p ds9 mode zoom
xpaset -p ds9 mode rotate
xpaset -p ds9 mode examine
xpaset -p ds9 mode pointer
echo "PASSED"
fi

if [ "$1" = "nameserver" ]; then
echo "Testing NameServer"
xpaset -p ds9 nameserver server simbad-sao
xpaset -p ds9 nameserver skyformat sexagesimal
xpaset -p ds9 nameserver name m31
xpaget ds9 nameserver server > /dev/null
xpaget ds9 nameserver skyformat > /dev/null
echo "PASSED"
fi

if [ "$1" = "orient" -o  -z "$1" ]; then
echo "Testing Orient"
xpaset -p ds9 orient none
xpaset -p ds9 orient x
xpaset -p ds9 orient y
xpaset -p ds9 orient xy
xpaget ds9 orient > /dev/null
xpaset -p ds9 frame reset
echo "PASSED"
fi

if [ "$1" = "pagesetup" -o  -z "$1" ]; then
echo "Testing Page Setup"
xpaset -p ds9 page setup orientation portrait
xpaset -p ds9 page setup pagescale scaled
xpaset -p ds9 page setup pagesize letter
xpaget ds9 page setup orientation > /dev/null
xpaget ds9 page setup pagescale > /dev/null
xpaget ds9 page setup pagesize > /dev/null
echo "PASSED"
fi

if [ "$1" = "pan" -o  -z "$1" ]; then
echo "Testing Pan"
xpaget ds9 pan physical > /dev/null
xpaget ds9 pan wcs fk5 sexagesimal > /dev/null
xpaset -p ds9 pan 100 100 image
xpaset -p ds9 pan to 13:29:55.666 +47:12:16.29 wcs fk5
xpaset -p ds9 frame reset
echo "PASSED"
fi

if [ "$1" = "pixeltable" -o  -z "$1" ]; then
echo "Testing PixelTable"
xpaget ds9 pixeltable > /dev/null
xpaset -p ds9 pixeltable
xpaset -p ds9 pixeltable yes
xpaset -p ds9 pixeltable no
echo "PASSED"
fi

if [ "$1" = "plot" -o  -z "$1" ]; then
echo "Testing Plot"

xpaget ds9 plot > /dev/null
cat xy.dat | xpaset ds9 plot new "Title" "X" "Y" xy
cat xye.dat | xpaset ds9 plot new "Title" "X" "Y" xyex
cat xye.dat | xpaset ds9 plot new "Title" "X" "Y" xyey
cat xyee.dat | xpaset ds9 plot new "Title" "X" "Y" xyexey
cat xye.stdin.dat | xpaset ds9 plot new stdin
sleep 1
xpaset -p ds9 plot close
xpaset -p ds9 plot close
xpaset -p ds9 plot close
xpaset -p ds9 plot close
xpaset -p ds9 plot close

xpaset -p ds9 plot new

xpaset -p ds9 plot load xy.dat xy
#xpaset -p ds9 plot save foo.dat
xpaset -p ds9 plot clear
xpaset -p ds9 plot saveconfig foo.plt
xpaset -p ds9 plot loadconfig foo.plt
#xpaset -p ds9 plot print
xpaset -p ds9 plot print destination file
xpaset -p ds9 plot print command "lp"
xpaset -p ds9 plot print filename "foo.ps"
xpaset -p ds9 plot print palette rgb
xpaset -p ds9 plot page orientation portrait
xpaset -p ds9 plot page pagescale scaled
xpaset -p ds9 plot page pagesize letter

xpaset -p ds9 plot graph grid yes
xpaset -p ds9 plot graph scale loglog
xpaset -p ds9 plot graph range x auto yes
xpaset -p ds9 plot graph range x min 0
xpaset -p ds9 plot graph range x max 100
xpaset -p ds9 plot graph range y auto yes
xpaset -p ds9 plot graph labels title "The Title"
xpaset -p ds9 plot graph labels xaxis "X"
xpaset -p ds9 plot graph labels yaxis "Y"

xpaset -p ds9 plot font numbers font times
xpaset -p ds9 plot font numbers size 12
xpaset -p ds9 plot font numbers style bold
xpaset -p ds9 plot font labels font times
xpaset -p ds9 plot font labels size 12
xpaset -p ds9 plot font labels style bold
xpaset -p ds9 plot font title font times
xpaset -p ds9 plot font title size 12
xpaset -p ds9 plot font title style bold

xpaset -p ds9 plot dataset 1

xpaset -p ds9 plot view discrete yes
xpaset -p ds9 plot view line yes
xpaset -p ds9 plot view step yes
xpaset -p ds9 plot view quadratic yes
xpaset -p ds9 plot view errorbar yes

xpaset -p ds9 plot color discrete red
xpaset -p ds9 plot view line green
xpaset -p ds9 plot view step blue
xpaset -p ds9 plot view quadratic cyan
xpaset -p ds9 plot view errorbar yellow

xpaset -p ds9 plot line discrete cross
xpaset -p ds9 plot line line width 2
xpaset -p ds9 plot line line dash yes
xpaset -p ds9 plot line step width 2
xpaset -p ds9 plot line step dash yes
xpaset -p ds9 plot line quadratic width 2
xpaset -p ds9 plot line quadratic dash yes
xpaset -p ds9 plot line errorbar width 2
xpaset -p ds9 plot line errorbar style no

xpaset -p ds9 plot close

echo "PASSED"
fi

if [ "$1" = "prefs" -o  -z "$1" ]; then
echo "Testing Prefs"
xpaget ds9 prefs mosaicfast > /dev/null
xpaget ds9 prefs bgcolor > /dev/null
xpaget ds9 prefs nancolor > /dev/null
xpaget ds9 prefs wcsprojection > /dev/null
xpaset -p ds9 prefs mosaicfast yes
xpaset -p ds9 prefs bgcolor black
xpaset -p ds9 prefs nancolor red
xpaset -p ds9 prefs wcsprojection fits
echo "PASSED"
fi

if [ "$1" = "print" -o  -z "$1" ]; then
echo "Testing Print"
xpaget ds9 print destination > /dev/null
xpaget ds9 print command > /dev/null
xpaget ds9 print palette > /dev/null
xpaget ds9 print level > /dev/null
xpaget ds9 print interpolate > /dev/null
xpaget ds9 print resolution > /dev/null
#xpaset -p ds9 print
xpaset -p ds9 print destination printer
xpaset -p ds9 print command lp
xpaset -p ds9 print filename ds9.ps
xpaset -p ds9 print palette rgb
xpaset -p ds9 print level 2
xpaset -p ds9 print interpolate no
xpaset -p ds9 print resolution 75
echo "PASSED"
fi

if [ "$1" = "regions" -o  -z "$1" ]; then
echo "Testing Regions"
echo "physical;circle(957,1027,40) # tag=foo" | xpaset ds9 regions

xpaget ds9 regions > /dev/null
xpaget ds9 regions fg > /dev/null
xpaget ds9 regions -format pros -system wcs -sky fk5 -skyformat sexagesimal -delim nl > /dev/null
xpaget ds9 regions format > /dev/null
xpaget ds9 regions system > /dev/null
xpaget ds9 regions sky > /dev/null
xpaget ds9 regions skyformat > /dev/null
xpaget ds9 regions strip > /dev/null
xpaget ds9 regions shape > /dev/null
xpaget ds9 regions color > /dev/null
xpaget ds9 regions width > /dev/null
xpaget ds9 regions delim > /dev/null
xpaget ds9 regions source > /dev/null
xpaget ds9 regions background > /dev/null
xpaget ds9 regions include > /dev/null
xpaget ds9 regions exclude > /dev/null
xpaget ds9 regions selected > /dev/null
xpaget ds9 regions -prop select yes > /dev/null
xpaget ds9 regions groups > /dev/null
xpaget ds9 regions -group foo > /dev/null

echo "image; circle 100 100 20" | xpaset ds9 regions
echo "image; circle 100 100 20" | xpaset ds9 regions bg
echo "fk5; circle 13:29:55 47:11:50 .5'" | xpaset ds9 regions
echo "physical; ellipse 100 100 20 40" | xpaset ds9 regions
echo "box 100 100 20 40 25" | xpaset ds9 regions
echo "image; line 100 100 200 400" | xpaset ds9 regions
echo "physical; ruler 200 300 200 400" | xpaset ds9 regions
echo "image; text 100 100 # text={Hello, World}" | xpaset ds9 regions
echo "fk4; boxcircle point 13:29:55 47:11:50" | xpaset ds9 regions

xpaset -p ds9 regions move front
xpaset -p ds9 regions move back
xpaset -p ds9 regions select all
xpaset -p ds9 regions select none
xpaset -p ds9 regions select group foo
xpaset -p ds9 regions delete all
xpaset -p ds9 regions delete select
xpaset -p ds9 regions load ds9.physical.reg
xpaset -p ds9 regions delete all
xpaset -p ds9 regions save foo.reg
xpaset -p ds9 regions format ds9
xpaset -p ds9 regions system wcs
xpaset -p ds9 regions sky fk5
xpaset -p ds9 regions skyformat degrees
xpaset -p ds9 regions delim nl
xpaset -p ds9 regions strip yes
xpaset -p ds9 regions shape ellipse
xpaset -p ds9 regions color red
xpaset -p ds9 regions width 2

xpaset -p ds9 regions group foo color red
xpaset -p ds9 regions group foo copy
xpaset -p ds9 regions group foo delete
xpaset -p ds9 regions group foo cut
xpaset -p ds9 regions group foo font {time 14 bold}
xpaset -p ds9 regions group foo move 100 100
xpaset -p ds9 regions group foo movefront
xpaset -p ds9 regions group foo moveback
xpaset -p ds9 regions group foo property delete no
xpaset -p ds9 regions group foo select

xpaset -p ds9 regions delete all
rm -f foo.reg
echo "PASSED"
fi

if [ "$1" = "rgb" -o  -z "$1" ]; then
echo "Testing RGB"
xpaset -p ds9 rgb > /dev/null
xpaget ds9 rgb channel > /dev/null
xpaget ds9 rgb view red > /dev/null
xpaget ds9 rgb view green > /dev/null
xpaget ds9 rgb view blue > /dev/null
xpaget ds9 rgb system > /dev/null
xpaget ds9 rgb lock scale > /dev/null
xpaget ds9 rgb lock bin > /dev/null
xpaget ds9 rgb lock colorbar > /dev/null
xpaset -p ds9 rgb green
xpaset -p ds9 rgb channel blue
xpaset -p ds9 rgb view blue off
xpaset -p ds9 rgb system wcs
xpaset -p ds9 rgb lock bin yes
xpaset -p ds9 rgb lock scale yes
xpaset -p ds9 rgb lock colorbar yes
xpaset -p ds9 frame delete
echo "PASSED"
fi

if [ "$1" = "rotate" -o  -z "$1" ]; then
echo "Testing Rotate"
xpaget ds9 rotate > /dev/null
xpaset -p ds9 rotate to 30
xpaset -p ds9 rotate 15
xpaset -p ds9 frame reset
echo "PASSED"
fi

if [ "$1" = "scale" -o  -z "$1" ]; then
echo "Testing Scale"
xpaget ds9 scale > /dev/null
xpaget ds9 scale limits > /dev/null
xpaget ds9 scale mode > /dev/null
xpaget ds9 scale scope > /dev/null
xpaget ds9 scale datasec > /dev/null
xpaset -p ds9 scale log
xpaset -p ds9 scale squared
xpaset -p ds9 scale sqrt
xpaset -p ds9 scale histequ
xpaset -p ds9 scale linear
xpaset -p ds9 scale minmax
xpaset -p ds9 scale zscale
xpaset -p ds9 scale zmax
xpaset -p ds9 scale user
xpaset -p ds9 scale mode zscale
xpaset -p ds9 scale mode zmax
xpaset -p ds9 scale mode 95
xpaset -p ds9 scale mode minmax
xpaset -p ds9 scale limits 0 100
xpaset -p ds9 scale global
xpaset -p ds9 scale local
xpaset -p ds9 scale scope global
xpaset -p ds9 scale scope local
xpaset -p ds9 scale mode minmax
xpaset -p ds9 scale zscale
xpaset -p ds9 scale datasec yes
echo "PASSED"
fi

if [ "$1" = "source" -o  -z "$1" ]; then
echo "Testing Source"
xpaset -p ds9 source source.tcl
echo "PASSED"
fi

if [ "$1" = "tcl" -o  -z "$1" ]; then
echo "Testing TCL"
#echo 'set bar "Hello Again, World"' | xpaset ds9 tcl
echo "PASSED"
fi

if [ "$1" = "single" -o  -z "$1" ]; then
echo "Testing Single/Blink/Tile"
xpaget ds9 tile > /dev/null
xpaget ds9 tile mode > /dev/null
xpaget ds9 blink > /dev/null
xpaset -p ds9 file new hst.fits
xpaset -p ds9 file new img16.fits
xpaset -p ds9 blink
xpaset -p ds9 single
xpaset -p ds9 tile
xpaset -p ds9 tile row
xpaset -p ds9 tile column
xpaset -p ds9 tile grid
xpaset -p ds9 single
xpaset -p ds9 frame delete
xpaset -p ds9 frame delete
echo "PASSED"
fi

if [ "$1" = "update" -o  -z "$1" ]; then
echo "Testing Update"
xpaset -p ds9 update
xpaset -p ds9 update 1 100 100 300 400
xpaset -p ds9 update off
xpaset -p ds9 update on
echo "PASSED"
fi

if [ "$1" = "version" -o  -z "$1" ]; then
echo "Testing Version"
xpaget ds9 version > /dev/null
echo "PASSED"
fi

if [ "$1" = "view" -o  -z "$1" ]; then
echo "Testing View"
sleep 1
xpaset -p ds9 frame delete
xpaget ds9 view info > /dev/null
xpaget ds9 view panner > /dev/null
xpaget ds9 view magnifier > /dev/null
xpaget ds9 view buttons > /dev/null
xpaget ds9 view colorbar > /dev/null
xpaget ds9 view horzgraph > /dev/null
xpaget ds9 view vertgraph > /dev/null
xpaget ds9 view horzgraph > /dev/null
xpaget ds9 view filename > /dev/null
xpaget ds9 view object > /dev/null
xpaget ds9 view minmax > /dev/null
xpaget ds9 view frame > /dev/null
xpaget ds9 view wcs > /dev/null
xpaget ds9 view detector > /dev/null
xpaget ds9 view amplifier > /dev/null
xpaget ds9 view physical > /dev/null
xpaget ds9 view image > /dev/null

xpaset -p ds9 view info no
xpaset -p ds9 view info yes
xpaset -p ds9 view panner no
xpaset -p ds9 view panner yes
xpaset -p ds9 view magnifier no
xpaset -p ds9 view magnifier yes
xpaset -p ds9 view buttons no
xpaset -p ds9 view buttons yes
xpaset -p ds9 view colorbar no
xpaset -p ds9 view colorbar yes
xpaset -p ds9 view horzgraph yes
xpaset -p ds9 view horzgraph no
xpaset -p ds9 view vertgraph yes
xpaset -p ds9 view vertgraph no
xpaset -p ds9 view filename no
xpaset -p ds9 view filename yes
xpaset -p ds9 view object yes
xpaset -p ds9 view object no
xpaset -p ds9 view minmax yes
xpaset -p ds9 view minmax no
xpaset -p ds9 view frame no
xpaset -p ds9 view frame yes
xpaset -p ds9 view wcs no
xpaset -p ds9 view wcs yes
xpaset -p ds9 view wcsa yes
xpaset -p ds9 view wcsa no
xpaset -p ds9 view detector yes
xpaset -p ds9 view detector no
xpaset -p ds9 view amplifier yes
xpaset -p ds9 view amplifier no
xpaset -p ds9 view physical no
xpaset -p ds9 view physical yes
xpaset -p ds9 view image no
xpaset -p ds9 view image yes
xpaset -p ds9 file new img16.fits
echo "PASSED"
fi

if [ "$1" = "wcs" -o  -z "$1" ]; then
echo "Testing WCS"
xpaget ds9 wcs > /dev/null
xpaget ds9 wcs system > /dev/null
xpaget ds9 wcs sky > /dev/null
xpaget ds9 wcs skyformat > /dev/null
xpaget ds9 wcs align > /dev/null
xpaset -p ds9 wcs wcs
xpaset -p ds9 wcs align yes
xpaset -p ds9 wcs system wcs
xpaset -p ds9 wcs sky galactic
xpaset -p ds9 wcs skyformat sexagesimal
xpaset -p ds9 wcs align no
xpaset -p ds9 wcs sky fk5
xpaset -p ds9 wcs skyformat degrees
cat image.wcs | xpaset ds9 wcs append
cat image.wcs | xpaset ds9 wcs replace
xpaset -p ds9 wcs append file image.wcs
xpaset -p ds9 wcs replace file image.wcs
xpaset -p ds9 wcs reset
echo "PASSED"
fi

if [ "$1" = "zoom" -o  -z "$1" ]; then
echo "Testing Zoom"
xpaset -p ds9 zoom 2
xpaset -p ds9 zoom to 4
xpaset -p ds9 zoom to fit
xpaget ds9 zoom > /dev/null
xpaset -p ds9 frame reset
echo "PASSED"
fi

if [ -z "$1" ]; then
echo "Testing Exit/Quit"
xpaset -p ds9 quit
echo "PASSED"
fi

echo "DONE"
